@@ -371,10 +371,10 @@ class GroupBy(gui.ToggleContainer):
         # Yuck...need to use an internal method to get the mask I need.
         tmp_coll = deepcopy(self._image_source)
         tmp_coll._find_keywords_by_values(**apply_to)
-        mask = tmp_coll.summary_info['file'].mask
+        mask = tmp_coll.summary['file'].mask
         # Note the logical not below; mask indicates which values
         # should be EXCLUDED.
-        filtered_table = tmp_coll.summary_info[~mask]
+        filtered_table = tmp_coll.summary[~mask]
         grouped_table = filtered_table.group_by(keywords)
         combine_groups = grouped_table.groups.keys
         group_list = []
@@ -740,7 +740,7 @@ class CalibrationStep(gui.ToggleContainer):
                 del new_select[closest]
                 file_name = self._master_source.files_filtered(master=True,
                                                                **new_select)
-                master_table = self._master_source.summary_info
+                master_table = self._master_source.summary
                 min_dist = 1e20
                 for name in file_name:
                     match = master_table['file'] == name
